@@ -11,6 +11,7 @@ import jsons
 class EnvVarSource(Enum):
     SSM = 'ssm'
     TEXT = 'text'
+    UNSET = 'unset'
 
 
 class AbstractEnvVarConfig:
@@ -30,6 +31,11 @@ class TextEnvVarConfig(AbstractEnvVarConfig):
         self.value = value
 
 
+class UnsetEnvVarConfig(AbstractEnvVarConfig):
+    def __init__(self):
+        super().__init__(EnvVarSource.UNSET)
+
+
 class S3BackendConfig:
     def __init__(
             self,
@@ -63,6 +69,8 @@ def env_var_deserializer(obj_dict, cls, **kwargs):
         return SSMEnvVarConfig(obj_dict['path'])
     if obj_dict['source'] == EnvVarSource.TEXT.value:
         return TextEnvVarConfig(obj_dict['value'])
+    if obj_dict['source'] == EnvVarSource.UNSET.value:
+        return UnsetEnvVarConfig()
 
     raise RuntimeError('Invalid Source')
 
@@ -82,6 +90,7 @@ class WrapperConfig:
             backends: BackendsConfig = None,
             depends_on: List[str] = None,
             config: bool = True,
+            audit_api_url: str = None,
             apply_automatically: bool = True,
             plugins: Dict[str, str] = None
     ):
@@ -93,5 +102,6 @@ class WrapperConfig:
         self.backends = backends
         self.depends_on = depends_on
         self.config = config
+        self.audit_api_url = audit_api_url
         self.apply_automatically = apply_automatically
         self.plugins = plugins or {}
